@@ -116,7 +116,7 @@ async fn benchmark_message(
             for _ in 0..iterations {
                 worker
                     .client
-                    .publish(DEFAULT_PRIORITY, test_topic.clone(), test_msg.as_slice())
+                    .publish(DEFAULT_PRIORITY, test_topic.clone(), (*test_msg).clone())
                     .await
                     .unwrap();
             }
@@ -313,10 +313,10 @@ async fn main() {
                     m.push(i as u8);
                 }
                 info!("msg.len = {}", m.len());
-                client.publish(DEFAULT_PRIORITY, topic, &m).await.unwrap();
+                client.publish(DEFAULT_PRIORITY, topic, m).await.unwrap();
             } else {
                 client
-                    .publish(DEFAULT_PRIORITY, topic, msg.as_bytes())
+                    .publish(DEFAULT_PRIORITY, topic, msg.as_bytes().to_vec())
                     .await
                     .unwrap();
             }
