@@ -559,13 +559,20 @@ impl Client {
         )
     }
 
+    /// Message is always vec to avoid unnecessary data copy
+    ///
     /// # Errors
     ///
     /// With return Err on communcation errors
-    pub async fn publish(&self, priority: u8, topic: String, message: &[u8]) -> Result<(), Error> {
+    pub async fn publish(
+        &self,
+        priority: u8,
+        topic: String,
+        message: Vec<u8>,
+    ) -> Result<(), Error> {
         exec_command!(
             self.control_channel,
-            ControlCommand::Publish(priority, topic, message.to_vec()),
+            ControlCommand::Publish(priority, topic, message),
             self.timeout
         )
     }
