@@ -605,6 +605,7 @@ async fn handle_stream(
 }
 
 #[allow(clippy::cast_precision_loss)]
+#[allow(clippy::too_many_lines)]
 async fn launch_data_stream(
     mut stream: SStream,
     addr: SocketAddr,
@@ -833,11 +834,11 @@ async fn run_server(
             *HOST_NAME.try_write().unwrap() = name.to_owned();
         }
     }
-    trace!("creating pid file {}, PID: {}", config.server.pid_file, pid);
     info!(
         "starting server, workers: {}, timeout: {:?}",
         config.server.workers, timeout
     );
+    info!("creating pid file {}, PID: {}", config.server.pid_file, pid);
     {
         PID_FILE
             .lock()
@@ -865,9 +866,9 @@ async fn run_server(
                         if len > UDP_BUF_LEN {
                             error!("udp packet from {} is too large ({})", addr, len);
                         } else {
-                            let frame: Vec<u8> = buf[..len].iter().map(|v| *v).collect();
+                            let frame: Vec<u8> = buf[..len].iter().copied().collect();
                             let ack_code = match process_udp_packet(frame).await {
-                                Ok(v) if v == true => Some(RESPONSE_OK),
+                                Ok(true) => Some(RESPONSE_OK),
                                 Err((e, need_ack)) => {
                                     error!("udp packet from {} error: {}", addr, e);
                                     if need_ack {
@@ -883,7 +884,10 @@ async fn run_server(
                                 _ => None,
                             };
                             if let Some(code) = ack_code {
-                                if let Err(e) = udp_sock.send_to(&[code], addr).await {
+                                let mut buf = CONTROL_HEADER.to_vec();
+                                buf.extend(&psrt::PROTOCOL_VERSION.to_le_bytes());
+                                buf.push(code);
+                                if let Err(e) = udp_sock.send_to(&buf, addr).await {
                                     error!("{}", e);
                                 }
                             }
@@ -966,7 +970,7 @@ async fn process_udp_packet(frame: Vec<u8>) -> Result<bool, (Error, bool)> {
         }
     } else {
         match authenticate(login, password).await {
-            Ok(v) if v == false => {
+            Ok(false) => {
                 return Err((Error::access("authentication failed"), need_ack));
             }
             Err(e) => {
@@ -1307,20 +1311,11 @@ mod stats {
         pub fn count_sent_bytes(&mut self, size: u64, latency: u32) {
             self.c_sent_messages += 1;
             self.c_sent_bytes += size;
-            self.c_sent_latency += latency as u64;
+            self.c_sent_latency += u64::from(latency);
         }
     }
 
-    macro_rules! ask_pass {
-        () => {
-            return Ok(Response::builder()
-                .status(StatusCode::UNAUTHORIZED)
-                .header("www-authenticate", "Basic realm=\"?\"")
-                .body(Body::from("".to_owned()))
-                .unwrap());
-        };
-    }
-
+    #[allow(clippy::too_many_lines)]
     async fn handler(req: Request<Body>) -> Result<Response<Body>, Infallible> {
         let (parts, _body) = req.into_parts();
         if parts.method == Method::GET {
@@ -1374,26 +1369,32 @@ mod stats {
             } else {
                 None
             };
+            let mut authorized = false;
             if let Some((ref login, ref password)) = credentials {
                 match super::authenticate(login, password).await {
-                    Ok(v) => {
-                        if !v {
-                            ask_pass!();
-                        }
+                    Ok(true) => {
                         if let Some(acl) = super::get_acl(login).await {
-                            if !acl.is_admin() {
-                                ask_pass!();
+                            if acl.is_admin() {
+                                authorized = true;
                             }
-                        } else {
-                            ask_pass!();
                         }
                     }
                     Err(e) => {
                         return response!(StatusCode::INTERNAL_SERVER_ERROR, e.to_string());
                     }
+                    _ => {}
                 }
-            } else {
-                ask_pass!();
+            } else if let Some(acl) = super::get_acl("_").await {
+                if acl.is_admin() {
+                    authorized = true;
+                }
+            }
+            if !authorized {
+                return Ok(Response::builder()
+                    .status(StatusCode::UNAUTHORIZED)
+                    .header("www-authenticate", "Basic realm=\"?\"")
+                    .body(Body::from("".to_owned()))
+                    .unwrap());
             }
             match path {
                 "/status" => {
